
/*
 * Kanatest
 *
 * Copyright (C) 2001-2004, 2006 Tomasz Maka <pasp@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef _OPTIONS_H
#define _OPTIONS_H

#define EXAMPLE_KANA_TEXT   "たわごと   ポンコツ"

enum {
    TO_DISABLED = 0,
    TO_1SEC,
    TO_2SEC,
    TO_3SEC,
    TO_ANYKEY
};

enum {
    SELECT_ALL = 0,
    SELECT_NONE,
    SELECT_INVERT
};

void update_example_text(void);
void options_create_window (GUI *appGUI);

#endif /* _OPTIONS_H */
